@@ -41,8 +41,7 @@ class Resolved:
                 self.channels[ID] = factory(guild=guild, data=c, state=state)
 
     def __repr__(self):
-        return "<Resolved users={0.users} members={0.members}\
-                roles={0.roles} channels={0.channels}>".format(self)
+        return "<Resolved users={0.users} members={0.members}roles={0.roles} channels={0.channels}>".format(self)
 
     def get(self, any_id):
         if any_id in self.members:
@@ -111,6 +110,23 @@ class InteractionDataOption:
     def __repr__(self):
         return "<InteractionDataOption name='{0.name}' value={0.value} options={0.options}>".format(self)
 
+    def _to_dict_values(self, connectors: dict=None):
+        connectors = connectors or {}
+        out = {}
+        for kw, val in self.options.items():
+            new_kw = connectors.get(kw, kw)
+            if val.type > 2:
+                out[new_kw] = val.value
+            else:
+                out[new_kw] = val
+        return out
+
+    @property
+    def sub_command(self):
+        opt = self.option_at(0)
+        if opt is not None and opt.type == 1:
+            return opt
+    
     def get_option(self, name: str):
         '''
         Get the raw :class:`InteractionDataOption` matching the specified name
@@ -181,6 +197,40 @@ class InteractionData:
     def __repr__(self):
         return "<InteractionData id={0.id} name='{0.name}' options={0.options}>".format(self)
 
+    def __getitem__(self, key):
+        if isinstance(key, str):
+            opt = self.get_option(key)
+        elif isinstance(key, int):
+            opt = self.option_at(key)
+        else:
+            raise TypeError(f'unsupported key type. Expected str or int, but received {type(key)} instead')
+        if opt is None:
+            return None
+        return opt.value if opt.type > 2 else opt
+
+    def _to_dict_values(self, connectors: dict=None):
+        connectors = connectors or {}
+        out = {}
+        for kw, val in self.options.items():
+            new_kw = connectors.get(kw, kw)
+            if val.type > 2:
+                out[new_kw] = val.value
+            else:
+                out[new_kw] = val._to_dict_values(connectors)
+        return out
+
+    @property
+    def sub_command(self):
+        opt = self.option_at(0)
+        if opt is not None and opt.type == 1:
+            return opt
+    
+    @property
+    def sub_command_group(self):
+        opt = self.option_at(0)
+        if opt is not None and opt.type == 2:
+            return opt
+
     def get_option(self, name: str):
         '''
         Get the raw :class:`InteractionDataOption` matching the specified name
@@ -214,10 +264,10 @@ class InteractionData:
         option: :class:`InteractionDataOption` | ``default``
             Otherwise
         '''
-        for n, o in self.options.items():
-            if n == name:
-                return o.value if o.type > 2 else o
-        return default
+        opt = self.options.get(name)
+        if opt is None:
+            return default
+        return opt.value if opt.type > 2 else opt
 
     def option_at(self, index: int):
         """
@@ -265,12 +315,18 @@ class SlashInteraction(BaseInteraction):
             guild=self.guild,
             state=state
         )
+        self.invoked_with = self.data.name
     
     def __repr__(self):
-        return "<SlashInteraction id={0.id} version={0.version} type={0.type} "\
-                "token='{0.token}' guild={0.guild} channel_id={0.channel_id} "\
-                "author={0.author} data={0.data!r}>".format(self)
-    
+        return (
+            "<SlashInteraction id={0.id} version={0.version} type={0.type} "
+            "token='{0.token}' guild={0.guild} channel={0.channel} "
+            "author={0.author} data={0.data!r}>"
+        ).format(self)
+
+    def __getitem__(self, key):
+        return self.data[key]
+
     def get(self, name: str, default=None):
         """Equivalent to :class:`InteractionData.get`"""
         return self.data.get(name, default)
